<?php 

if (!defined("ABSPATH")) {
    exit;
}

if (!class_exists("BindCommerce_Mapping")) {

    /**
     * 
     * The BindCommerce_Mapping main class
     * 
     * @since 1.0.1
     * 
     */
    class BindCommerce_Mapping extends BindCommerce {

       
        /**
         * 
         * Create/Update a mapping order state
         * 
         * @since 1.0.1
         * 
         */
        public static function order_state($mapping_active, $mapping_order_id="", $order_state_name, $id_order_state, $new_order_stock_type=0, $update_order_stock_type=0, $delete=false) {
            
            // Check if valid data
            if (empty($order_state_name) || empty($id_order_state)) {
                return false;
            }

            global $wpdb;
            
            // Check if already exist
            $mapping_order_exist = "";

            if (is_numeric($mapping_order_id) && $mapping_order_id > 0) {

                $mapping_order_exist = BindCommerce_DB::get_result("
    
                    SELECT  mapping_order_id 
                    FROM " . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_BINDCOMMERCE_TABLE_MAPPING_IMPORT_ORDERS . " " . "
                    WHERE   mapping_order_id    = '" . $mapping_order_id . "';
    
                ");

            } else {

                $mapping_order_exist = BindCommerce_DB::get_result("
    
                    SELECT  mapping_order_id 
                    FROM " . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_BINDCOMMERCE_TABLE_MAPPING_IMPORT_ORDERS . " " . "
                    WHERE   mapping_order_bindcommerce_name    = '" . $order_state_name . "';
    
                ");

            }


            if ( is_numeric($mapping_order_exist) && $mapping_order_exist > 0) {

                // Delete 

                if ($delete) {                     
                    
                    $where = [ 
                        'mapping_order_id' => $mapping_order_id
                    ];

                    $result = $wpdb->delete(
                        BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_BINDCOMMERCE_TABLE_MAPPING_IMPORT_ORDERS, 
                        $where 
                    );

                    if ($result) {
                        return true; 
                    }              
                    return false;  

                }

                // Update

                $data = [ 
                    'mapping_active'                        => sanitize_text_field(BindCommerce_Tools::str_sanitize($mapping_active)),
                    'mapping_order_bindcommerce_name'       => sanitize_text_field(BindCommerce_Tools::str_sanitize($order_state_name)),
                    'id_order_state'                        => sanitize_text_field(BindCommerce_Tools::str_sanitize($id_order_state)),
                    'mapping_order_new_order_stock_type'    => sanitize_text_field(BindCommerce_Tools::str_sanitize($new_order_stock_type)),
                    'mapping_order_update_order_stock_type' => sanitize_text_field(BindCommerce_Tools::str_sanitize($update_order_stock_type))
                ];               

                $where = [ 
                    'mapping_order_id' => $mapping_order_id
                ];

                $result = $wpdb->update(
                    BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_BINDCOMMERCE_TABLE_MAPPING_IMPORT_ORDERS, 
                    $data, 
                    $where 
                );

                if ($result) {
                    return true; 
                }              
                return false;  

            }

            // Create

            $result = $wpdb->insert( BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_BINDCOMMERCE_TABLE_MAPPING_IMPORT_ORDERS, [   
                    'mapping_active'                        => sanitize_text_field(BindCommerce_Tools::str_sanitize($mapping_active)),
                    'mapping_order_bindcommerce_name'       => sanitize_text_field(BindCommerce_Tools::str_sanitize($order_state_name)),
                    'id_order_state'                        => sanitize_text_field(BindCommerce_Tools::str_sanitize($id_order_state)),
                    'mapping_order_new_order_stock_type'    => sanitize_text_field(BindCommerce_Tools::str_sanitize($new_order_stock_type)),
                    'mapping_order_update_order_stock_type' => sanitize_text_field(BindCommerce_Tools::str_sanitize($update_order_stock_type))
                ]
            );

            if ($result) {
                return true; 
            }              
            return false;


    
        }

       
        /**
         * 
         * Get mapping order states
         * 
         * @since 1.0.1
         * 
         */
        public static function get_order_states_mapped() {

            $mappings = BindCommerce_DB::get_results("

                SELECT * 
                FROM " . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_BINDCOMMERCE_TABLE_MAPPING_IMPORT_ORDERS . ";

            ");

            if ( !empty($mappings) ) {
                return $mappings; 
            }

            return false;
    
        }


        /**
         * 
         * Get WooCommerce Order state by BindCommerce Order state name 
         * 
         * @since 1.0.1
         * 
         */
        public static function get_wc_order_state_by_mapping_state_name($order_state_name) {
            
            $id_order_state = BindCommerce_DB::get_result("

                SELECT  id_order_state
                FROM " . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_BINDCOMMERCE_TABLE_MAPPING_IMPORT_ORDERS . " " . "
                WHERE   mapping_active = '1'
                AND     mapping_order_bindcommerce_name = '" . $order_state_name . "';

            ");

            if ( !empty($id_order_state) ) {
                return $id_order_state; 
            }

            return false;
    
        }


        /**
         * 
         * Get for new order the mapping stock type stored
         * 
         * @since 1.0.1
         * 
         */
        public static function get_mapping_order_state_new_order_stock_type($order_state_name) {
            
            $id_order_state = BindCommerce_DB::get_result("

                SELECT  mapping_order_new_order_stock_type
                FROM " . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_BINDCOMMERCE_TABLE_MAPPING_IMPORT_ORDERS . " " . "
                WHERE   mapping_order_bindcommerce_name    = '" . $order_state_name . "';

            ");

            if ( !empty($id_order_state) ) {
                return $id_order_state; 
            }

            return false;


    
        }


        /**
         * 
         * Get for update order the mapping stock type stored
         * 
         * @since 1.0.1
         * 
         */
        public static function get_mapping_order_state_update_order_stock_type($order_state_name) {
            
            $id_order_state = BindCommerce_DB::get_result("

                SELECT  mapping_order_update_order_stock_type
                FROM " . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_BINDCOMMERCE_TABLE_MAPPING_IMPORT_ORDERS . " " . "
                WHERE   mapping_order_bindcommerce_name    = '" . $order_state_name . "';

            ");

            if ( !empty($id_order_state) ) {
                return $id_order_state; 
            }

            return false;


    
        }

    }

}


?>