<?php

if ( ! defined( 'ABSPATH' ) ) { 
    exit; 
}


if ( ! class_exists( 'BindCommerce_Order' ) ) {

    /**
     * 
     * BindCommerce_Order class 
     * 
     * @since 1.0.0
     * 
     */
    class BindCommerce_Order extends BindCommerce {


        /**
         * 
         * Create WooCommerce order
         * 
         * @since 1.0.0
         * 
         */
        public static function insert_orders( $orders, $limit = "", $order_by = "", $import_new_orders = false ) {

            BindCommerce_Logger::info( __("Importazione avviata", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );

            $orders_xml    = simplexml_load_string( $orders );
            $orders_json   = json_encode($orders_xml);
            $orders_array  = json_decode($orders_json, true);
            $orders        = $orders_array["Document"];
            $orders_limit  = $limit;
            $order_by      = $order_by;

            $single_order = array();

            // Check if $orders is only one order, if yes make as a multi array to not conflict with the next functions
            foreach ($orders as $order) {

                if (!isset($order["General"]["bindCommerceNumber"])) {
                    $single_order[] = $orders;
                    break;
                }

            }

            if (!empty($single_order)) {
                $orders = $single_order;
            }
            
            if ( $order_by == "asc" || $order_by == "ASC" ) {
                asort($orders);
            } 

            if ( $orders_limit == "-1" || empty($orders_limit) ) {

                $orders_limit = count($orders);

            } 

            $limit_count = 0;          

            foreach ($orders as $order) {
                
                if ($limit_count == $orders_limit) {
                    break;
                }

                // Check if order state is mapped with BindCommerce state
                $wc_id_order_state = BindCommerce_Mapping::get_wc_order_state_by_mapping_state_name($order["General"]["StateName"]);

                if (!$wc_id_order_state) {
                    continue;
                }
                
                $wc_order_id = self::get_id_order_by_general_bindcommerce_number($order["General"]["bindCommerceNumber"]);

                if (!$wc_order_id && strtolower($order["General"]["Technology"]) == "ecommerce woocommerce") {

                    $wc_order_id = self::get_id_order_by_general_number($order["General"]["Number"]);

                }

                // Check if order already exist in WC
                if ( !empty($wc_order_id) ) {

                    if ($import_new_orders) {
                        continue;
                    }

                    self::update_order($wc_order_id, $order);
                    $limit_count++;
                    continue;

                }

                if (!$import_new_orders) {
                    continue;
                }

                // Create the WC order
                self::new_order($order);   
                $limit_count++;
                
            }
       
            BindCommerce_Logger::info( __("Importazione completata", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );
            
            return "Import completed";

        
        }



        
        /**
         * 
         * Create a new WooCommerce order
         * 
         * @since 1.0.1
         * 
         */
        public static function new_order( $order ) {
            
            $wc_order_id = self::get_id_order_by_general_bindcommerce_number($order["General"]["bindCommerceNumber"]);

            if (!$wc_order_id && strtolower($order["General"]["Technology"]) == "ecommerce woocommerce") {

                $wc_order_id = self::get_id_order_by_general_number($order["General"]["Number"]);

            }

            // Check if order already exist in WC than update
            if ( !empty($wc_order_id) ) {

                return self::update_order($wc_order_id, $order);

            }

            $wc_order = wc_create_order();                     
            $wc_order_id = $wc_order->save();

            global $wpdb;
            $wpdb->insert( BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_SYNC_IMPORT_ORDERS, [
                    'woocommerce_order_id'      => $wc_order_id,
                    'bindcommerce_order_number' => $order["General"]["bindCommerceNumber"],
                ]
            );                

            $billing_address_2 = "";

            if (!empty($order["Customer"]["MobPhone"])) {

                $billing_address_2 .= "Cellulare: " . $order["Customer"]["MobPhone"];

            }

            if (!empty($order["Customer"]["VatCode"])) {

                $billing_address_2 .= " Partita IVA: " . $order["Customer"]["VatCode"];

            }

            if (!empty($order["Customer"]["EInvoiceDestCode"])) {

                $billing_address_2 .= " SDI: " . $order["Customer"]["EInvoiceDestCode"];

            }

            if (!empty($order["Customer"]["Pec"])) {

                $billing_address_2 .= " PEC: " . $order["Customer"]["Pec"];

            }

            $billing_address = array(
                'first_name' => !empty($order["Customer"]["Name"])          ? strval($order["Customer"]["Name"])        : "",
                'last_name'  => !empty($order["Customer"]["Surname"])       ? strval($order["Customer"]["Surname"])     : "",
                'company'    => !empty($order["Customer"]["Company"])       ? strval($order["Customer"]["Company"])     : "",
                'email'      => !empty($order["Customer"]["Email"])         ? strval($order["Customer"]["Email"])       : "",
                'phone'      => !empty($order["Customer"]["Phone"])         ? strval($order["Customer"]["Phone"])       : "",
                'address_1'  => !empty($order["Customer"]["Address"])       ? strval($order["Customer"]["Address"])     : "",
                'address_2'  => !empty($billing_address_2)                  ? strval($billing_address_2)                : "",
                'city'       => !empty($order["Customer"]["City"])          ? strval($order["Customer"]["City"])        : "",
                'state'      => !empty($order["Customer"]["Province"])      ? strval($order["Customer"]["Province"])    : "",
                'postcode'   => !empty($order["Customer"]["Postcode"])      ? strval($order["Customer"]["Postcode"])    : "",
                'country'    => !empty($order["Customer"]["CountryCode"])   ? strval($order["Customer"]["CountryCode"]) : ""
            );


            $shipping_address_2 = "";

            if (!empty($order["Delivery"]["MobPhone"])) {

                $shipping_address_2 .= "Cellulare: " . $order["Delivery"]["MobPhone"];

            }

            $shipping_address = array(
                'first_name' => !empty($order["Delivery"]["Name"])          ? strval($order["Delivery"]["Name"])        : "",
                'last_name'  => !empty($order["Delivery"]["Surname"])       ? strval($order["Delivery"]["Surname"])     : "",
                'company'    => !empty($order["Delivery"]["Company"])       ? strval($order["Delivery"]["Company"])     : "",
                'email'      => !empty($order["Delivery"]["Email"])         ? strval($order["Delivery"]["Email"])       : "",
                'phone'      => !empty($order["Delivery"]["Phone"])         ? strval($order["Delivery"]["Phone"])       : "",
                'address_1'  => !empty($order["Delivery"]["Address"])       ? strval($order["Delivery"]["Address"])     : "",
                'address_2'  => !empty($shipping_address_2)                 ? strval($shipping_address_2)               : "",
                'city'       => !empty($order["Delivery"]["City"])          ? strval($order["Delivery"]["City"])        : "",
                'state'      => !empty($order["Delivery"]["Province"])      ? strval($order["Delivery"]["Province"])    : "",
                'postcode'   => !empty($order["Delivery"]["Postcode"])      ? strval($order["Delivery"]["Postcode"])    : "",
                'country'    => !empty($order["Delivery"]["CountryCode"])   ? strval($order["Delivery"]["CountryCode"]) : ""
            );


            // Add custom order meta data ID from import
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_BINDCOMMERCE_NUMBER,   
                !empty($order["General"]["bindCommerceNumber"])     ? strval($order["General"]["bindCommerceNumber"]) : "" 
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_DOCUMENT_TYPE,         
                !empty($order["General"]["DocumentType"])           ? strval($order["General"]["DocumentType"]) : ""        
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_NUMBER,                
                !empty($order["General"]["Number"])                 ? strval($order["General"]["Number"]) : ""             
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_NODE,                  
                !empty($order["General"]["Node"])                   ? strval($order["General"]["Node"]) : ""               
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_NODE_ID,               
                !empty($order["General"]["NodeID"])                 ? strval($order["General"]["NodeID"]) : ""             
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_TECHNOLOGY,            
                !empty($order["General"]["Technology"])             ? strval($order["General"]["Technology"]) : ""         
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_MARKET,                
                !empty($order["General"]["Market"])                 ? strval($order["General"]["Market"]) : ""             
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_DATE,                  
                !empty($order["General"]["Date"])                   ? strval($order["General"]["Date"]) : ""               
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_LAST_UPDATE,           
                !empty($order["General"]["LastUpdate"])             ? strval($order["General"]["LastUpdate"]) : ""         
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_STATE_BIND_ID,         
                !empty($order["General"]["StatebindID"])            ? strval($order["General"]["StatebindID"]) : ""         
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_STATE_CODE,            
                !empty($order["General"]["StateCode"])              ? strval($order["General"]["StateCode"]) : ""           
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_STATE_NAME,            
                !empty($order["General"]["StateName"])              ? strval($order["General"]["StateName"]) : ""          
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_AMOUNTS_TOTAL,                 
                !empty($order["Amounts"]["Total"])                  ? strval($order["Amounts"]["Total"]) : ""              
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_AMOUNTS_TOTAL_WITHOUT_TAX,     
                !empty($order["Amounts"]["TotalWithoutTax"])        ? strval($order["Amounts"]["TotalWithoutTax"]) : ""     
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_AMOUNTS_TOTAL_SHIPPING_COST,   
                !empty($order["Amounts"]["ShippingCost"])           ? strval($order["Amounts"]["ShippingCost"]) : ""       
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_AMOUNTS_CURRENCY,              
                !empty($order["Amounts"]["Currency"])               ? get_woocommerce_currency_symbol($order["Amounts"]["Currency"]) : "" 
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_SHIPPING_CARRIER,              
                !empty($order["Shipping"]["Carrier"])               ? strval($order["Shipping"]["Carrier"]) : ""           
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_SHIPPING_TRACKING_NUMBER,      
                !empty($order["Shipping"]["TrackingNumber"])        ? strval($order["Shipping"]["TrackingNumber"]) : ""     
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_SHIPPING_TRANSPORTED_WEIGHT,  
                !empty($order["Shipping"]["TransportedWeight"])     ? strval($order["Shipping"]["TransportedWeight"]) : "" 
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_SHIPPING_SHIPPED_TIME,         
                !empty($order["Shipping"]["ShippedTime"])           ? strval($order["Shipping"]["ShippedTime"]) : ""       
            );

            $order_items = $wc_order->get_items(); // Get the products that already exist in the order

            if (!empty($order_items)) {

                foreach ( $order_items as $item_id => $item ) {
                    
                    $wc_order->remove_item( $item_id );

                }
            }
            

            $missing_products   = [];
            $order_products     = $order["Rows"];

            foreach ($order_products as $order_row) {   
                
                if ( !isset($order_row[0]) ) {

                    $product_array = $order_row;
                    $order_row = array();
                    $order_row[] = $product_array;

                }                    

                foreach ($order_row as $product) {  

                    $wc_product_id  = wc_get_product_id_by_sku($product["Code"]);                    
                
                    if (!$wc_product_id) {   

                        $missing_product_currency = get_woocommerce_currency_symbol( $product["Currency"] );
                    
                        $missing_products[] = [
                            "product" => [

                                "Code"                  => $product["Code"],
                                "Description"           => $product["Description"],
                                "Picture"               => $product["Picture"],
                                "Qty"                   => $product["Qty"],
                                "VatRate"               => Round( $product["VatRate"], 2 ),
                                "TotalVatExcluded"      => Round( $product["TotalVatExcluded"], 2 ),
                                "Total"                 => Round( $product["Total"], 2 ),
                                "TotalDiscounted"       => Round( $product["TotalDiscounted"], 2 ),
                                "Currency"              => $missing_product_currency,

                            ]
                        ];         

                    } else {

                        $wc_product = wc_get_product($wc_product_id);
    
                        if ( !empty($product["TotalDiscounted"]) ) {
                            
                            $args = [
                                "total" => $product["TotalDiscounted"]
                            ];
    
                        } else {
    
                            $args = [
                                "total" => $product["Total"]
                            ];
    
                        }
    
                        if ($wc_product) {       
                            
                            $wc_order->add_product( $wc_product, $product["Qty"], $args); // Add WC product ID and Quantity        

                            $product_quantity = (int) $product["Qty"];
                            $set_quantity = true;

                            // Check if order stock status is set for this mapping order
                            $mapping_order_stock_status = BindCommerce_Mapping::get_mapping_order_state_new_order_stock_type($order["General"]["StateName"]);
                            if (!$mapping_order_stock_status) {
                                $set_quantity = false;
                            }
                            
                            if ( $wc_product->is_type('simple') == true ) {
                                $stock_quantity = get_post_meta( $wc_product_id, BINDCOMMERCE_PRODUCT_META_SIMPLE_QUANTITY, true );
                            }            

                            if ( $wc_product->is_type('variation') == true ) {
                                $stock_quantity = get_post_meta( $wc_product_id, BINDCOMMERCE_PRODUCT_META_VARIATION_QUANTITY, true );
                            }

                            $product_stock_quantity = $wc_product->get_stock_quantity();
                            
                            if (!$product_stock_quantity && $product_stock_quantity !== 0) {
                                $set_quantity = false;
                            }

                            if ($set_quantity && $mapping_order_stock_status == "stock_up") {
                           
                                $product_quantity = $stock_quantity + $product_quantity;
                                $wc_product->set_stock_quantity($product_quantity);

                            }

                            if ($set_quantity && $mapping_order_stock_status == "stock_down") {
                            
                                $product_quantity = $stock_quantity - $product_quantity;
                                $wc_product->set_stock_quantity($product_quantity);

                            }

                            
                        }   

                    }
                    
                }

            }    

            if ( !empty($missing_products) ) {
                
                $wc_order->update_meta_data( BINDCOMMERCE_ORDER_META_MISSING_PRODUCTS, json_encode( ["products" => $missing_products] ) );

            }

            
            
            // Set addresses
            $wc_order->set_address( $billing_address , 'billing' );
            $wc_order->set_address( $shipping_address, 'shipping' );
            
            // Set payment gateway
            //$payment_gateways = WC()->payment_gateways->payment_gateways();
            //$order->set_payment_method( $payment_gateways['bacs'] );
            
            // Set order totals
            $wc_order->set_total($order["Amounts"]["Total"]);
            $wc_order->set_currency($order["Amounts"]["Currency"]);

            // Set discounts
            $wc_order->set_discount_total($order["Amounts"]["CouponDiscount"]);
            
            // Set shipping totals
            $wc_order->set_shipping_tax($order["Amounts"]["ShippingTax"]);
            $wc_order->set_shipping_total($order["Amounts"]["ShippingCost"]);              

            // Update order status
            $wc_order_status = [
                "name"  => BindCommerce_Mapping::get_wc_order_state_by_mapping_state_name($order["General"]["StateName"]),
                "label" => __("bindCommerce:", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)
            ];
            $wc_order->update_status( $wc_order_status["name"], $wc_order_status["label"], true);

            // Save order
            $wc_order_id = $wc_order->save();
        
            BindCommerce_Logger::info( __("Ordine ID: " . $wc_order_id . " creato", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );
            
            return $wc_order_id;

        }



        /**
         * 
         * Update WooCommerce order
         * 
         * @since 1.0.1
         * 
         */
        public static function update_order( $order_id, $order ) {
            
            $wc_order = wc_get_order( $order_id );

            if (empty($wc_order)) {
                return false;
            }

            $billing_address_2 = "";

            if (!empty($order["Customer"]["MobPhone"])) {

                $billing_address_2 .= "Cellulare: " . $order["Customer"]["MobPhone"];

            }

            if (!empty($order["Customer"]["VatCode"])) {

                $billing_address_2 .= " Partita IVA: " . $order["Customer"]["VatCode"];

            }

            if (!empty($order["Customer"]["EInvoiceDestCode"])) {

                $billing_address_2 .= " SDI: " . $order["Customer"]["EInvoiceDestCode"];

            }

            if (!empty($order["Customer"]["Pec"])) {

                $billing_address_2 .= " PEC: " . $order["Customer"]["Pec"];

            }

            $billing_address = array(
                'first_name' => !empty($order["Customer"]["Name"])          ? strval($order["Customer"]["Name"])        : "",
                'last_name'  => !empty($order["Customer"]["Surname"])       ? strval($order["Customer"]["Surname"])     : "",
                'company'    => !empty($order["Customer"]["Company"])       ? strval($order["Customer"]["Company"])     : "",
                'email'      => !empty($order["Customer"]["Email"])         ? strval($order["Customer"]["Email"])       : "",
                'phone'      => !empty($order["Customer"]["Phone"])         ? strval($order["Customer"]["Phone"])       : "",
                'address_1'  => !empty($order["Customer"]["Address"])       ? strval($order["Customer"]["Address"])     : "",
                'address_2'  => !empty($billing_address_2)                  ? strval($billing_address_2)                : "",
                'city'       => !empty($order["Customer"]["City"])          ? strval($order["Customer"]["City"])        : "",
                'state'      => !empty($order["Customer"]["Province"])      ? strval($order["Customer"]["Province"])    : "",
                'postcode'   => !empty($order["Customer"]["Postcode"])      ? strval($order["Customer"]["Postcode"])    : "",
                'country'    => !empty($order["Customer"]["CountryCode"])   ? strval($order["Customer"]["CountryCode"]) : ""
            );


            $shipping_address_2 = "";

            if (!empty($order["Delivery"]["MobPhone"])) {

                $shipping_address_2 .= "Cellulare: " . $order["Delivery"]["MobPhone"];

            }

            $shipping_address = array(
                'first_name' => !empty($order["Delivery"]["Name"])          ? strval($order["Delivery"]["Name"])        : "",
                'last_name'  => !empty($order["Delivery"]["Surname"])       ? strval($order["Delivery"]["Surname"])     : "",
                'company'    => !empty($order["Delivery"]["Company"])       ? strval($order["Delivery"]["Company"])     : "",
                'email'      => !empty($order["Delivery"]["Email"])         ? strval($order["Delivery"]["Email"])       : "",
                'phone'      => !empty($order["Delivery"]["Phone"])         ? strval($order["Delivery"]["Phone"])       : "",
                'address_1'  => !empty($order["Delivery"]["Address"])       ? strval($order["Delivery"]["Address"])     : "",
                'address_2'  => !empty($shipping_address_2)                 ? strval($shipping_address_2)               : "",
                'city'       => !empty($order["Delivery"]["City"])          ? strval($order["Delivery"]["City"])        : "",
                'state'      => !empty($order["Delivery"]["Province"])      ? strval($order["Delivery"]["Province"])    : "",
                'postcode'   => !empty($order["Delivery"]["Postcode"])      ? strval($order["Delivery"]["Postcode"])    : "",
                'country'    => !empty($order["Delivery"]["CountryCode"])   ? strval($order["Delivery"]["CountryCode"]) : ""
            );


            // Add custom order meta data ID from import
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_BINDCOMMERCE_NUMBER,   
                !empty($order["General"]["bindCommerceNumber"])     ? strval($order["General"]["bindCommerceNumber"]) : "" 
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_DOCUMENT_TYPE,         
                !empty($order["General"]["DocumentType"])           ? strval($order["General"]["DocumentType"]) : ""        
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_NUMBER,                
                !empty($order["General"]["Number"])                 ? strval($order["General"]["Number"]) : ""             
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_NODE,                  
                !empty($order["General"]["Node"])                   ? strval($order["General"]["Node"]) : ""               
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_NODE_ID,               
                !empty($order["General"]["NodeID"])                 ? strval($order["General"]["NodeID"]) : ""             
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_TECHNOLOGY,            
                !empty($order["General"]["Technology"])             ? strval($order["General"]["Technology"]) : ""         
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_MARKET,                
                !empty($order["General"]["Market"])                 ? strval($order["General"]["Market"]) : ""             
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_DATE,                  
                !empty($order["General"]["Date"])                   ? strval($order["General"]["Date"]) : ""               
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_LAST_UPDATE,           
                !empty($order["General"]["LastUpdate"])             ? strval($order["General"]["LastUpdate"]) : ""         
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_STATE_BIND_ID,         
                !empty($order["General"]["StatebindID"])            ? strval($order["General"]["StatebindID"]) : ""         
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_STATE_CODE,            
                !empty($order["General"]["StateCode"])              ? strval($order["General"]["StateCode"]) : ""           
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_GENERAL_STATE_NAME,            
                !empty($order["General"]["StateName"])              ? strval($order["General"]["StateName"]) : ""          
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_AMOUNTS_TOTAL,                 
                !empty($order["Amounts"]["Total"])                  ? strval($order["Amounts"]["Total"]) : ""              
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_AMOUNTS_TOTAL_WITHOUT_TAX,     
                !empty($order["Amounts"]["TotalWithoutTax"])        ? strval($order["Amounts"]["TotalWithoutTax"]) : ""     
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_AMOUNTS_TOTAL_SHIPPING_COST,   
                !empty($order["Amounts"]["ShippingCost"])           ? strval($order["Amounts"]["ShippingCost"]) : ""       
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_AMOUNTS_CURRENCY,              
                !empty($order["Amounts"]["Currency"])               ? get_woocommerce_currency_symbol($order["Amounts"]["Currency"]) : "" 
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_SHIPPING_CARRIER,              
                !empty($order["Shipping"]["Carrier"])               ? strval($order["Shipping"]["Carrier"]) : ""           
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_SHIPPING_TRACKING_NUMBER,      
                !empty($order["Shipping"]["TrackingNumber"])        ? strval($order["Shipping"]["TrackingNumber"]) : ""     
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_SHIPPING_TRANSPORTED_WEIGHT,  
                !empty($order["Shipping"]["TransportedWeight"])     ? strval($order["Shipping"]["TransportedWeight"]) : "" 
            );
            $wc_order->update_meta_data( 
                BINDCOMMERCE_ORDER_META_SHIPPING_SHIPPED_TIME,         
                !empty($order["Shipping"]["ShippedTime"])           ? strval($order["Shipping"]["ShippedTime"]) : ""       
            );

            $order_items = $wc_order->get_items(); // Get the products that already exist in the order

            if (!empty($order_items)) {

                foreach ( $order_items as $item_id => $item ) {
                    
                    $wc_order->remove_item( $item_id );

                }
            }            

            $missing_products   = [];
            $order_products     = $order["Rows"];

            foreach ($order_products as $order_row) {   
                
                if ( !isset($order_row[0]) ) {

                    $product_array = $order_row;
                    $order_row = array();
                    $order_row[] = $product_array;

                }                    

                foreach ($order_row as $product) {  

                    $wc_product_id  = wc_get_product_id_by_sku($product["Code"]);                    
                
                    if (!$wc_product_id) {   

                        $missing_product_currency = get_woocommerce_currency_symbol( $product["Currency"] );
                    
                        $missing_products[] = [
                            "product" => [

                                "Code"                  => $product["Code"],
                                "Description"           => $product["Description"],
                                "Picture"               => $product["Picture"],
                                "Qty"                   => $product["Qty"],
                                "VatRate"               => Round( $product["VatRate"], 2 ),
                                "TotalVatExcluded"      => Round( $product["TotalVatExcluded"], 2 ),
                                "Total"                 => Round( $product["Total"], 2 ),
                                "TotalDiscounted"       => Round( $product["TotalDiscounted"], 2 ),
                                "Currency"              => $missing_product_currency,

                            ]
                        ];         

                    } else {

                        $wc_product = wc_get_product($wc_product_id);
    
                        if ( !empty($product["TotalDiscounted"]) ) {
                            
                            $args = [
                                "total" => $product["TotalDiscounted"]
                            ];
    
                        } else {
    
                            $args = [
                                "total" => $product["Total"]
                            ];
    
                        }
    
                        if ($wc_product) {       
                            
                            $wc_order->add_product( $wc_product, $product["Qty"], $args); // Add WC product ID and Quantity
                            
                            $product_quantity = (int) $product["Qty"];
                            $set_quantity = true;

                            // Check if order stock status is set for this mapping order
                            $mapping_order_stock_status = BindCommerce_Mapping::get_mapping_order_state_new_order_stock_type($order["General"]["StateName"]);
                            if (!$mapping_order_stock_status) {
                                $set_quantity = false;
                            }
                            
                            if ( $wc_product->is_type('simple') == true ) {
                                $stock_quantity = get_post_meta( $wc_product_id, BINDCOMMERCE_PRODUCT_META_SIMPLE_QUANTITY, true );
                            }            

                            if ( $wc_product->is_type('variation') == true ) {
                                $stock_quantity = get_post_meta( $wc_product_id, BINDCOMMERCE_PRODUCT_META_VARIATION_QUANTITY, true );
                            }

                            $product_stock_quantity = $wc_product->get_stock_quantity();
                            
                            if (!$product_stock_quantity && $product_stock_quantity !== 0) {
                                $set_quantity = false;
                            }

                            if ($set_quantity && $mapping_order_stock_status == "stock_up") {
                           
                                $product_quantity = $stock_quantity + $product_quantity;
                                $wc_product->set_stock_quantity($product_quantity);

                            }

                            if ($set_quantity && $mapping_order_stock_status == "stock_down") {
                            
                                $product_quantity = $stock_quantity - $product_quantity;
                                $wc_product->set_stock_quantity($product_quantity);

                            }
                            
                        }   

                    }
                    
                }

            }    

            if ( !empty($missing_products) ) {
                
                $wc_order->update_meta_data( BINDCOMMERCE_ORDER_META_MISSING_PRODUCTS, json_encode( ["products" => $missing_products] ) );

            }
            
            
            // Set addresses
            $wc_order->set_address( $billing_address , 'billing' );
            $wc_order->set_address( $shipping_address, 'shipping' );
            
            // Set payment gateway
            //$payment_gateways = WC()->payment_gateways->payment_gateways();
            //$order->set_payment_method( $payment_gateways['bacs'] );
            
            // Set order totals
            $wc_order->set_total($order["Amounts"]["Total"]);
            $wc_order->set_currency($order["Amounts"]["Currency"]);

            // Set discounts
            $wc_order->set_discount_total($order["Amounts"]["CouponDiscount"]);
            
            // Set shipping totals
            $wc_order->set_shipping_tax($order["Amounts"]["ShippingTax"]);
            $wc_order->set_shipping_total($order["Amounts"]["ShippingCost"]);              

            // Update order status
            $wc_order_status = [
                "name"  => BindCommerce_Mapping::get_wc_order_state_by_mapping_state_name($order["General"]["StateName"]),
                "label" => __("bindCommerce:", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)
            ];
            $wc_order->update_status( $wc_order_status["name"], $wc_order_status["label"], true);

            // Save order
            $wc_order_id = $wc_order->save();
       
            BindCommerce_Logger::info( __("Ordine con ID: " . $order_id . " aggiornato", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );
            
            return $wc_order_id;
        
        }

        
        /**
         * 
         * Check if order already exist in WooCommerce by BindCommerce Number, than return WooCommerce ID order
         * 
         * @since 1.0.1
         * 
         */
        private static function get_id_order_by_general_bindcommerce_number( $bindcommerce_order_number ) {
            
            $wc_order_id = BindCommerce_DB::get_result("

                SELECT woocommerce_order_id 
                FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_SYNC_IMPORT_ORDERS . " " . "
                WHERE  bindcommerce_order_number = '" . $bindcommerce_order_number . "';

            ");

            if (is_numeric($wc_order_id) && $wc_order_id > 0) {
                return $wc_order_id;
            }

            return false;

        }

        
        /**
         * 
         * Check if order already exist in WooCommerce by BindCommerce Order Number, than return WooCommerce ID order
         * 
         * @since 1.0.1
         * 
         */
        private static function get_id_order_by_general_number( $order_number ) {
                        
            $wc_order = wc_get_order( $order_number );

            if (empty($wc_order)) {
                return false;
            }

            return $order_number;

        }


        /**
         * 
         * Get all WooCoommerce order states
         * 
         * @since 1.0.1
         * 
         */
        public static function get_wc_order_states() {

            $order_states = wc_get_order_statuses();

            $arr = [];
        
            foreach ($order_states as $order_state => $name) { 
                    
                $arr[] = [
                    "order_state_id"            => $order_state,
                    "order_state_name"          => $name
                ];

            }

            return $arr;

        }


    }

}

?>