<?php

if (!defined("ABSPATH")) {
    exit;
}

if (!class_exists("BindCommerce_Tools")) {
    
    /**
     * 
     * The BindCommerce_Tools class
     *
     * @since 1.0.1
     * 
     */ 
    class BindCommerce_Tools extends BindCommerce {
        

        /**
         * 
         * Return a sanitized string
         * 
         * @since 1.0.1
         * 
         */
        public static function str_sanitize($string) {
        
            $str = $string;
            $str = str_replace("'","\'", $str);
            $str = str_replace("/","-", $str);
            return $str;
            
        }


        /**
         * 
         * Get a random string without special characters
         * 
         * @since 1.0.1
         * 
         */
        public static function generate_random_text($lenght=16) {

            $str = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
            $code = "";
            for( $i=0; $i<$lenght; $i++ ){

                $code .= substr($str, rand(0, strlen($str)), 1);   

            }

            return $code;   
            
        }    


        /**
         * 
         * Get current module URL with SSL or not
         * 
         * @since 1.0.1
         *  
         */
        public static function get_plugin_url() {

            return plugins_url( "\/bindcommerce\/" );

        }


        /**
         * 
         * Check if variable is a valid XML format
         * 
         * @since 1.0.1
         * 
         */
        public static function is_valid_xml( $value ) {

            $prev = libxml_use_internal_errors(true);
        
            $doc = simplexml_load_string($value);
            $errors = libxml_get_errors();
        
            libxml_clear_errors();
            libxml_use_internal_errors($prev);
        
            return false !== $doc && empty($errors);

        }


        /**
         * 
         * Transform array to XML
         * 
         * @since 1.0.1
         * 
         */
        public static function api_array_to_xml( $data, $name="root", $export_mode="full", &$doc=null, &$node=null ){

            if ($doc==null){
                $doc = new DOMDocument('1.0','UTF-8');
                $doc->formatOutput = TRUE;
                $node = $doc;
            }

            if (is_array($data)){
                foreach($data as $var=>$val){

                    if (is_numeric($var)) {

                        self::api_array_to_xml($val, $name, $export_mode, $doc, $node);

                    } else {

                        if (!isset($child)){

                            $child = $doc->createElement($name);
                            $node->appendChild($child);
                            
                            if($name == "bindCommerceProducts") {
                                $child->setAttribute( 'Mode', 'full' );
                            }

                        }

                        self::api_array_to_xml($val, $var, $export_mode, $doc, $child);
                    }

                }
            } else {
                $child = $doc->createElement($name);
                $node->appendChild($child);
                $textNode = $doc->createTextNode($data);
                $child->appendChild($textNode);
            }

            if ($doc==$node) {
                return $doc->saveXML();
            }

        }


        /**
         * 
         * Unique multimensional array data
         * 
         * @since 1.0.1
         * 
         */
        public static function unique_multidimensional_array($array, $key){

            $temp_array = array();
            $i = 0;
            $key_array = array();
            
            foreach($array as $val){
                if(!in_array($val[$key],$key_array)){
                    $key_array[$i] = $val[$key];
                    $temp_array[$i] = $val;
                }
                $i++;
            }
            return $temp_array; 

        }


        /**
         * 
         * Check if current user can edit based on default Wordpress user roles
         * 
         * @since 1.0.1
         * 
         */
        public static function user_can_edit() {

            $user = wp_get_current_user();
            $allowed_roles = array("editor", "administrator", "author");

            if( array_intersect($allowed_roles, $user->roles ) ) { 
                return true;
            }
            return false;
    
        }


    } 

}