<?php

require_once( dirname(__FILE__)."../../../autoload.php" );

if (!defined("ABSPATH")) {
    exit;
}


if (!class_exists("BindCommerce_Cron_ExportProducts")) {

    /**
     * 
     * Tha cron class that allow to export products to BindCommerce
     *
     * @since 1.0.1
     * 
     */ 
    class BindCommerce_Cron_ExportProducts extends BindCommerce {

        public function init()
        {        
            // CHECK token 
            if ( !isset($_GET["token"]) || !BindCommerce_Cron::is_valid_token($_GET["token"]) ) { 
                            
                return json_encode( [
                    "status"    => "error",
                    "message"   => __("Token di sicurezza non valido", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
                    "logs" => [ 
                        0 => [
                            "data" => __("Il token di sicurezza per effettuare la richiesta non è valido.", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) 
                        ]
                    ]
                ]);

            }  
            
            // PROCESS request 
            $errors         = [];
            $product_ids    = $_GET["product_id"];
            $start_by       = $_GET["start_by"];
            $end_by         = $_GET["end_by"];
            $limit          = $_GET["limit"];
            $order_by       = $_GET["order_by"];
            $mode           = $_GET["mode"];
            $type           = $_GET["type"];

            if (empty($product_ids) ) {

                $product_ids = bindcommerce_get_wc_products(    
                                
                    array( 
                        "return"   => "ids",
                        "limit"    => -1,
                    )

                );

            } else {

                $product_ids = explode(",", $product_ids );

                foreach ($product_ids as $p_id) {

                    $product = wc_get_product( $p_id ); 

                    if ( !$product ) {

                        BindCommerce_Logger::warning( __("Il prodotto con ID: ", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . $p_id . __(" non esiste", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) ) ;
                        
                        $errors[] = [
                            "data" => __( "Il prodotto con ID: ", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . $p_id . __( " non esiste", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)
                        ];
                        break;            
                        
                    }

                }
                

            }      

            if ( isset($start_by) && is_numeric($start_by) && $start_by > 0 ) {

                foreach ($product_ids as $pid) {

                    if ($pid < $start_by) {

                        $product_ids = array_diff( $product_ids, [$pid] );

                    }

                }

            }

            if ( isset($end_by) && is_numeric($end_by) && $end_by > 0 ) {

                foreach ($product_ids as $pid) {

                    if ($pid > $end_by) {

                        $product_ids = array_diff( $product_ids, [$pid] );

                    }

                }

            }

            if ( empty($product_ids) ) {

                BindCommerce_Logger::warning( __("Nessun prodotto trovato.", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) ) ;
                $errors[] = [
                    "data" => __( "Nessun prodotto trovato.", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)
                ];

            }
            
            if ( !empty($errors) ) {

                BindCommerce_Logger::error( __("EXPORT Prodotti: Impossibile completare la sincronizzazione, per maggiori informazioni consulta i log catturati nella sezione dedicata", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN), "", true );

                return json_encode( [
                    "status"    => "error",
                    "message"   => __("Impossibile completare la sincronizzazione", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
                    "logs"      => $errors
                ]);

            }

            if ( isset($limit) && is_numeric($limit) 
                || isset($limit) && empty($limit) 
                || isset($limit) && $limit == "-1" 
                || !isset($limit) 
                || isset($order_by) && $order_by == "ASC"
                || isset($order_by) && $order_by == "DESC"
                || isset($mode) && empty($mode) 
                || !isset($mode) 
                || isset($mode) && $mode == "full" 
                || isset($mode) && $mode == "quantity" 
                || isset($mode) && $mode == "price" 
                || isset($type) && $type == "full"
                || isset($type) && $type == "incremental"
                ) 
            {

                $sync = json_decode( 

                    BindCommerce_API::export_products( 
                        $product_ids, 
                        $limit, 
                        $order_by, 
                        $mode, 
                        "text/xml", 
                        false, 
                        $type 
                    ),

                true );
                
                if (isset($sync["status"]) && $sync["status"] == "error") {
                                    
                    $errors[] = [
                        "data" => $sync["message"]
                    ];
            
                }

            } else {

                BindCommerce_Logger::error( __("Parametri Sync non validi.", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );

                $errors[] = [
                    "data" => __( "Parametri Sync non validi.", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)
                ];

            }    

            if ( !empty($errors) ) {

                BindCommerce_Logger::error( __("EXPORT Prodotti: Impossibile completare la sincronizzazione, per maggiori informazioni consulta i log catturati nella sezione dedicata", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN), "", true );

                return json_encode( [
                    "status"    => "error",
                    "message"   => __("Impossibile completare la sincronizzazione", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
                    "logs"      => $errors
                ]);
                
            }

            BindCommerce_Logger::info( __("EXPORT Prodotti: Esportazione completata", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );

            return json_encode( [
                "status"    => "success",
                "message"   => __("Esportazione completata", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
                "logs"      => [ 
                    0 => [
                        "data" => __("Tutti i contenuti sono stati correttamente sincronizzati", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) 
                    ]
                ],
            ]);

        }
        
    }

}

$bindcommerce_ajax = new BindCommerce_Cron_ExportProducts();
header("Content-Type: application/json; charset=utf-8");
echo json_encode($bindcommerce_ajax->init());
die();


?>