<?php

require_once( dirname(__FILE__).'../../../autoload.php' );

if (!defined("ABSPATH")) {
    exit;
}


if (!class_exists("BindCommerce_Cron_ImportOrder")) {

    /**
     * 
     * Tha Cron class that allow to import orders from bindCommerce to WooCommerce
     *
     * @since 1.0.1
     * 
     */ 
    class BindCommerce_Cron_ImportOrder extends BindCommerce {

        public function init()
        {        

            // CHECK token 
            if ( !isset($_GET["token"]) || !BindCommerce_Cron::is_valid_token($_GET["token"]) ) { 
                
                return json_encode( [
                    "status"    => "error",
                    "message"   => __("Token di sicurezza non valido", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
                    "logs" => [ 
                        0 => [
                            "data" => __("Il token di sicurezza per effettuare la richiesta non è valido.", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) 
                        ]
                    ]
                ]);

            }  

            // PROCESS request 
            $errors = [];
            $order_ids          = -1;   
            $import_new_orders  = true;

            if ( isset($_GET["order_by"]) && empty($_GET["order_by"]) ) {

                BindCommerce_Logger::error( __("Ordinamento Sync non valido.", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );

                $errors[] = [
                    "data" => __( "Ordinamento Sync non valido.", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)
                ];

            }
            
            if ( !empty($errors) ) {

                BindCommerce_Logger::error( __("Impossibile completare la sincronizzazione, per maggiori informazioni consulta i log catturati nella sezione dedicata", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN), "", true );

                return json_encode( [
                    "status"    => "error",
                    "message"   => __("Impossibile completare la sincronizzazione", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
                    "logs"      => $errors
                ]);

            }

            if ( isset($_GET["limit"]) && is_numeric($_GET["limit"]) 
                || isset($_GET["limit"]) && empty($_GET["limit"])         
                || isset($_GET["limit"]) && $_GET["limit"] == "-1"
                || !isset($_GET["limit"]) )  
            {

                $sync = json_decode( BindCommerce_API::import_orders( 
                    $order_ids, 
                    $_GET["limit"],
                    $_GET["order_by"], 
                    $import_new_orders 
                ), true );
                
                if (isset($sync["status"]) && $sync["status"] == "error") {

                    $errors[] = [
                        "data" => $sync["message"]
                    ];

                }

            } else {

                BindCommerce_Logger::error( __("Limite Sync non valido.", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );

                $errors[] = [
                    "data" => __( "Limite Sync non valido.", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)
                ];

            }  

            if ( !empty($errors) ) {

                BindCommerce_Logger::error( __("IMPORT Ordini: Impossibile completare la richiesta, per maggiori informazioni consulta i log catturati nella sezione dedicata", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN), "", true );

                return json_encode( [
                    "status"    => "error",
                    "message"   => __("Impossibile completare la richiesta", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
                    "logs"      => $errors
                ]);

            }             

            BindCommerce_Logger::info( __("IMPORT Ordini: Tutti i contenuti sono stati correttamente sincronizzati", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );

            return json_encode( [
                "status"    => "success",
                "message"   => __("Ordini importati con successo", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
                "logs"      => [ 
                    0 => [
                        "data" => __("Tutti i contenuti sono stati correttamente sincronizzati", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) 
                    ]
                ],
            ]);

        }

    }

}

$bindcommerce_cron = new BindCommerce_Cron_ImportOrder();
header("Content-Type: application/json; charset=utf-8");
echo $bindcommerce_cron->init();
die();


?>