<?php 

if ( ! defined( 'ABSPATH' ) ) { 
    exit; 
}


// WooCommerce Product Tab Integration

add_filter('woocommerce_product_data_tabs', function($tabs) {

	$tabs['bindcommerce_settings'] = [
		'label' => __('bindCommerce', BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
		'target' => 'bindcommerce_product_data',
		'class' => ['hide_if_external', 'hide_if_grouped'],
		'priority' => 99
	];
	return $tabs;

});


add_action('woocommerce_product_data_panels', function() { ?>

    <div id="bindcommerce_product_data" class="panel woocommerce_options_panel hidden hide_if_grouped">    
        <?php 

            $wc_product     = wc_get_product();
            $wc_product_id  = $wc_product->get_id();

            woocommerce_wp_text_input([
                "id"                => "bindcommerce_export_product_button",
                "label"             => __("Sincronizza su", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . " <span style='color: #89aa0d;font-weight: 700;'>" . __("bindCommerce", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . "</span>",
                "placeholder"       => __("Avvia Sync", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
                "wrapper_class"     => "hide_if_grouped",
                "custom_attributes" => [
                    "readonly"          => "readonly",
                    "data-product-id"   => $wc_product_id
                ],
            ]);

            woocommerce_wp_checkbox([
                "id"                =>  BINDCOMMERCE_PRODUCT_META_SYNC ,
                "label"             => __("Disabilita Sync Prodotto", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
                "wrapper_class"     => "hide_if_grouped", 
            ]);

            woocommerce_wp_text_input([
                "id"                =>  "bindcommerce_sync_tip_message" ,
                "label"             => __("Valori alternativi da inviare a bindCommerce (se non compilati verranno inviati quelli standard)", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
                "wrapper_class"     => "hide_if_variable hide_if_grouped",
                "custom_attributes" => [
                    "readonly"          => "readonly"
                ],
            ]);

            woocommerce_wp_text_input([
                "id"                =>  BINDCOMMERCE_PRODUCT_META_SIMPLE_REGULAR_PRICE ,
                "label"             => __("Prezzo di listino (", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . get_woocommerce_currency() . __(") " , BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . "<span style='color: #89aa0d;font-weight: 700;'>" . __("bindCommerce", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . "</span>",
                "placeholder"       => __("Es. 19.99", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
                "wrapper_class"     => "hide_if_variable hide_if_grouped",
            ]);

            woocommerce_wp_text_input([
                "id"                =>  BINDCOMMERCE_PRODUCT_META_SIMPLE_SALE_PRICE ,
                "label"             => __("Prezzo in offerta (", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . get_woocommerce_currency() . __(") " , BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . "<span style='color: #89aa0d;font-weight: 700;'>" . __("bindCommerce", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . "</span>",
                "placeholder"       => __("Es. 9.99", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
                "wrapper_class"     => "hide_if_variable hide_if_grouped",
            ]);

            woocommerce_wp_text_input([
                "id"                =>  BINDCOMMERCE_PRODUCT_META_SIMPLE_QUANTITY ,
                "label"             => __("Quantità prodotto su", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . " <span style='color: #89aa0d;font-weight: 700;'>" . __("bindCommerce", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . "</span>",
                "placeholder"       => __("Es. 10", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
                "wrapper_class"     => "hide_if_variable hide_if_grouped",      
                "desc_tip"          => true,
                "description"       => __( "Attenzione: questo è un campo non scalabile con valore fisso non mutabile al ricevimento di un ordine. Lasciare vuoto se si desiderasse utilizzare le quantità di default di WooCommerce", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN )
            ]);

            
            if ( BindCommerce_Setting::get_tax_amount_status() ) {
                
                woocommerce_wp_text_input([
                    "id"                =>  BINDCOMMERCE_PRODUCT_META_SIMPLE_TAX_AMOUNT ,
                    "label"             => __("Aliquota IVA", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . "<span style='color: #ff0000;'>(%)</span> <span style='color: #89aa0d;font-weight: 700;'>" . __("bindCommerce", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . "</span>",
                    "placeholder"       => __("Es. 22%", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
                    "wrapper_class"     => "hide_if_variable hide_if_grouped", 
                ]);

            }

            
            if ( BindCommerce_Setting::get_supplement_amount_status() ) {

                woocommerce_wp_text_input([
                    'id'                => BINDCOMMERCE_PRODUCT_META_SIMPLE_SUPPLEMENT_AMOUNT,
                    "label"             => __("Ricarico", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . " <span style='color: #89aa0d;font-weight: 700;'>" . __("bindCommerce", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . "</span>",
                    'placeholder'       => __('Es. 15% - 9.99 - ecc', BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
                    'wrapper_class'     => 'hide_if_variable hide_if_grouped', 
                ]);

            }
                        

            if ( BindCommerce_Setting::get_gtin_fields_status() ) {

                woocommerce_wp_text_input([
                    'id'            =>  BINDCOMMERCE_PRODUCT_META_SIMPLE_GTIN ,
                    'label'         => __('Codice GTIN', BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
                    'placeholder'   => __('XXXXXXXXXXXXX', BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
                    'wrapper_class' => 'hide_if_variable hide_if_grouped', 
                ]);

            }

        ?>
    </div>

<?php });

function bindcommerce_woocommerce_display_product_attributes($product_attributes, $product){

    if ( BindCommerce_Setting::get_gtin_fields_status() && BindCommerce_Setting::get_gtin_front_end_fields_status() ) {

        $product_id = $product->get_ID();
        $wc_product = wc_get_product($product_id);

        if( $wc_product->is_type( 'simple' ) ){ 

            $product_attributes['bindcommerce_gtin_code'] = [
                'label' => __('Codice GTIN', BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
                'value' => get_post_meta( $product_id, BINDCOMMERCE_PRODUCT_META_SIMPLE_GTIN, true ),
            ];

        }

        if( $wc_product->is_type( 'variable' ) ){         

            foreach ( $wc_product->get_children( false ) as $child_id ) {
                            
                $variation = new BindCommerce_Product( $child_id );

                if ( !$variation->_wc_product || !$variation->_wc_product->exists() ) {

                    continue;

                }

                $variation_title    = "";
                $variation_gtin     = $variation->get_product_gtin(); 
                $attributes         = array_keys( $variation->_wc_product->get_variation_attributes(false) );            

                foreach ($attributes as $attribute) {

                    if (empty($variation_title)) {

                        $variation_title .= ucfirst( wc_attribute_label($attribute) ) . " - " . $variation->_wc_product->get_attribute($attribute);

                    } else {

                        $variation_title .= "<br />" . ucfirst( wc_attribute_label($attribute) ) . " - " . $variation->_wc_product->get_attribute($attribute);

                    }

                }    

                $product_attributes['bindcommerce_gtin_code_' . $child_id] = [
                    'label' => __('Codice GTIN: <br />', BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . $variation_title,
                    'value' => $variation_gtin,
                ];


            }
            
        }
        
    }
    
    return $product_attributes;

}
add_filter('woocommerce_display_product_attributes', 'bindcommerce_woocommerce_display_product_attributes', 10, 2);




add_action('woocommerce_process_product_meta', function($post_id) {

    $product = wc_get_product($post_id);   

    if ( BindCommerce_Setting::get_gtin_fields_status() ) {

        if (isset($_POST[ BINDCOMMERCE_PRODUCT_META_SIMPLE_GTIN ])) {

            $product->update_meta_data( BINDCOMMERCE_PRODUCT_META_SIMPLE_GTIN , sanitize_text_field($_POST[ BINDCOMMERCE_PRODUCT_META_SIMPLE_GTIN ]));

        }

    }

    if (isset($_POST[ BINDCOMMERCE_PRODUCT_META_SYNC ])) {

        $product->update_meta_data( BINDCOMMERCE_PRODUCT_META_SYNC , 'yes');  

    } else {

        $product->update_meta_data( BINDCOMMERCE_PRODUCT_META_SYNC , '');  

    }
    
    if (isset($_POST[ BINDCOMMERCE_PRODUCT_META_SIMPLE_REGULAR_PRICE ])) {

        $product_regular_price = sanitize_text_field($_POST[ BINDCOMMERCE_PRODUCT_META_SIMPLE_REGULAR_PRICE ]);
        $product_regular_price = str_replace(",", ".", $product_regular_price);
        $product_regular_price = str_replace(" ", "", $product_regular_price);

        if (is_numeric($product_regular_price)) {

            $product->update_meta_data( BINDCOMMERCE_PRODUCT_META_SIMPLE_REGULAR_PRICE , round($product_regular_price, 2) );

        } else {

            $product->update_meta_data( BINDCOMMERCE_PRODUCT_META_SIMPLE_REGULAR_PRICE , "");

        }     

    } 

    if (isset($_POST[ BINDCOMMERCE_PRODUCT_META_SIMPLE_SALE_PRICE ])) {

        $product_sale_price = sanitize_text_field($_POST[ BINDCOMMERCE_PRODUCT_META_SIMPLE_SALE_PRICE ]);
        $product_sale_price = str_replace(",", ".", $product_sale_price);
        $product_sale_price = str_replace(" ", "", $product_sale_price);

        if (is_numeric($product_sale_price)) {

            $product->update_meta_data( BINDCOMMERCE_PRODUCT_META_SIMPLE_SALE_PRICE , round($product_sale_price, 2) );

        } else {

            $product->update_meta_data( BINDCOMMERCE_PRODUCT_META_SIMPLE_SALE_PRICE , "");

        }     

    } 

    if (isset($_POST[ BINDCOMMERCE_PRODUCT_META_SIMPLE_QUANTITY ])) {
        
        $product_quantity = sanitize_text_field($_POST[ BINDCOMMERCE_PRODUCT_META_SIMPLE_QUANTITY ]);
        $product_quantity = str_replace(",", ".", $product_quantity);
        $product_quantity = str_replace(" ", "", $product_quantity);

        if (is_numeric($product_quantity)) {

            $product->update_meta_data(  BINDCOMMERCE_PRODUCT_META_SIMPLE_QUANTITY , round($product_quantity) );

        } else {

            $product->update_meta_data(  BINDCOMMERCE_PRODUCT_META_SIMPLE_QUANTITY , "" );

        }     
        
    }

    
    if ( BindCommerce_Setting::get_tax_amount_status() ) {

        if (isset($_POST[ BINDCOMMERCE_PRODUCT_META_SIMPLE_TAX_AMOUNT ])) {
            
            $product_tax_amount = sanitize_text_field($_POST[ BINDCOMMERCE_PRODUCT_META_SIMPLE_TAX_AMOUNT ]);
            $product_tax_amount = str_replace(",", ".", $product_tax_amount);
            $product_tax_amount = str_replace("%", "", $product_tax_amount);
            $product_tax_amount = str_replace(" ", "", $product_tax_amount);

            if (is_numeric($product_tax_amount)) {

                $product->update_meta_data( BINDCOMMERCE_PRODUCT_META_SIMPLE_TAX_AMOUNT , round($product_tax_amount, 2) . "%");

            } else {

                $product->update_meta_data( BINDCOMMERCE_PRODUCT_META_SIMPLE_TAX_AMOUNT , "");

            }     
            
        }

    }

    
    if ( BindCommerce_Setting::get_supplement_amount_status() ) {

        if (isset($_POST[BINDCOMMERCE_PRODUCT_META_SIMPLE_SUPPLEMENT_AMOUNT])) {

            $product_supplement_amount = sanitize_text_field($_POST[BINDCOMMERCE_PRODUCT_META_SIMPLE_SUPPLEMENT_AMOUNT]);
            $product_supplement_amount = str_replace(",", ".", $product_supplement_amount);
            $product_supplement_amount = str_replace(" ", "", $product_supplement_amount);
            
            if (strpos($product_supplement_amount, '%') !== false) {

                $product_supplement_amount = str_replace("%", "", $product_supplement_amount);

                if (is_numeric($product_supplement_amount)) {

                    $product->update_meta_data(BINDCOMMERCE_PRODUCT_META_SIMPLE_SUPPLEMENT_AMOUNT, round($product_supplement_amount, 2) . "%");

                } else {

                    $product->update_meta_data(BINDCOMMERCE_PRODUCT_META_SIMPLE_SUPPLEMENT_AMOUNT, "");

                } 

            } else {

                if (is_numeric($product_supplement_amount)) {

                    $product->update_meta_data(BINDCOMMERCE_PRODUCT_META_SIMPLE_SUPPLEMENT_AMOUNT, round($product_supplement_amount, 2) );

                } else {

                    $product->update_meta_data(BINDCOMMERCE_PRODUCT_META_SIMPLE_SUPPLEMENT_AMOUNT, "");

                } 

            }
            
        }

    }
    
    $product->save();

});

// -----------------------------------------
// 1. Add custom field input @ Product Data > Variations > Single Variation
 
add_action( 'woocommerce_variation_options_pricing', 'bindcommerce_add_custom_fields_to_variations', 10, 3 );
 
if ( !function_exists( 'bindcommerce_add_custom_fields_to_variations' ) ) {

    function bindcommerce_add_custom_fields_to_variations( $loop, $variation_data, $variation ) {

        woocommerce_wp_text_input( [

            "id"                    => BINDCOMMERCE_PRODUCT_META_VARIATION_REGULAR_PRICE . "[" . $loop . "]",
            "label"                 => __("Prezzo variazione (", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . get_woocommerce_currency() . __(") " , BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . "<span style='color: #89aa0d;font-weight: 700;'>" . __("bindCommerce", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . "</span>",
            "placeholder"           => __("Es. 19.99", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
            "wrapper_class"         => "form-row form-row-first",
            "value"                 => get_post_meta( $variation->ID, BINDCOMMERCE_PRODUCT_META_VARIATION_REGULAR_PRICE, true )

        ] );

        woocommerce_wp_text_input( [

            "id"                    => BINDCOMMERCE_PRODUCT_META_VARIATION_SALE_PRICE . "[" . $loop . "]",
            "label"                 => __("Prezzo variazione in offerta (", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . get_woocommerce_currency() . __(") " , BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . "<span style='color: #89aa0d;font-weight: 700;'>" . __("bindCommerce", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . "</span>",
            "placeholder"           => __("Es. 19.99", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
            "wrapper_class"         => "form-row form-row-last",
            "value"                 => get_post_meta( $variation->ID, BINDCOMMERCE_PRODUCT_META_VARIATION_SALE_PRICE, true )

        ] );

        woocommerce_wp_text_input( [

            "id"                    => BINDCOMMERCE_PRODUCT_META_VARIATION_QUANTITY . "[" . $loop . "]",
            "label"                 => __("Quantità prodotto su", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . " <span style='color: #89aa0d;font-weight: 700;'>" . __("bindCommerce", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . "</span>",
            "placeholder"           => __("Es. 10", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
            "wrapper_class"         => "form-row form-row-first",
            "value"                 => get_post_meta( $variation->ID, BINDCOMMERCE_PRODUCT_META_VARIATION_QUANTITY, true ),
            "desc_tip"              => true,
            "description"           => __( "Attenzione: questo è un campo non scalabile con valore fisso non mutabile al ricevimento di un ordine. Lasciare vuoto se si desiderasse utilizzare le quantità di default di WooCommerce", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN )
        

        ] );        

        if ( BindCommerce_Setting::get_gtin_fields_status() ) {

            woocommerce_wp_text_input( [

                "id"                => BINDCOMMERCE_PRODUCT_META_VARIATION_GTIN . "[" . $loop . "]",
                "label"             => __( "Codice GTIN", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN ),
                "placeholder"       => __("XXXXXXXXXXXXX", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
                "wrapper_class"     => "form-row form-row-last",
                "value"             => get_post_meta( $variation->ID, BINDCOMMERCE_PRODUCT_META_VARIATION_GTIN, true ),          

            ] );
            
        }

        /*

        woocommerce_wp_text_input( [

            'id'                    => BINDCOMMERCE_PRODUCT_META_VARIATION_TAX_AMOUNT . '[' . $loop . ']',
            'label'                 => __('Aliquota IVA Variazione <span style="color: #ff0000;">(%)</span> <span style="color: #89aa0d;font-weight: 700;">bindCommerce</span>', BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
            'placeholder'           => __('Es. 22%', BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
            'wrapper_class'         => 'form-row form-row-first',
            'value'                 => get_post_meta( $variation->ID, BINDCOMMERCE_PRODUCT_META_VARIATION_TAX_AMOUNT, true )

        ] );

        */

        /*

        woocommerce_wp_text_input( [

            'id'                    => BINDCOMMERCE_PRODUCT_META_VARIATION_SUPPLEMENT_AMOUNT . '[' . $loop . ']',
            'label'                 => __('Ricarico Variazione <span style="color: #89aa0d;font-weight: 700;">bindCommerce</span>', BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
            'placeholder'           => __('Es. 15% - 9.99 - ecc', BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
            'wrapper_class'         => 'form-row form-row-last',
            'value'                 => get_post_meta( $variation->ID, BINDCOMMERCE_PRODUCT_META_VARIATION_SUPPLEMENT_AMOUNT, true )

        ] );

        */

    }


}
 
// -----------------------------------------
// 2. Save custom field on product variation save
 
add_action( 'woocommerce_save_product_variation', 'bindcommerce_save_custom_fields_variations', 10, 2 );
 
if ( !function_exists( 'bindcommerce_save_custom_fields_variations' ) ) {

    function bindcommerce_save_custom_fields_variations( $variation_id, $i ) {

        $regular_price_fields = sanitize_text_field( $_POST[BINDCOMMERCE_PRODUCT_META_VARIATION_REGULAR_PRICE][$i] );

        if ( isset( $regular_price_fields ) ) {

            $regular_price_fields = str_replace(",", ".", $regular_price_fields);
            $regular_price_fields = str_replace(" ", "", $regular_price_fields);

            if (is_numeric($regular_price_fields)) {

                update_post_meta( $variation_id, BINDCOMMERCE_PRODUCT_META_VARIATION_REGULAR_PRICE, esc_attr( round($regular_price_fields, 2) ) );

            } else {

                update_post_meta( $variation_id, BINDCOMMERCE_PRODUCT_META_VARIATION_REGULAR_PRICE, "" );

            }   

        }

        $sale_price_fields = sanitize_text_field( $_POST[BINDCOMMERCE_PRODUCT_META_VARIATION_SALE_PRICE][$i] );

        if ( isset( $sale_price_fields ) ) {

            $sale_price_fields = str_replace(",", ".", $sale_price_fields);
            $sale_price_fields = str_replace(" ", "", $sale_price_fields);

            if (is_numeric($sale_price_fields)) {

                update_post_meta( $variation_id, BINDCOMMERCE_PRODUCT_META_VARIATION_SALE_PRICE, esc_attr( round($sale_price_fields, 2) ) );

            } else {

                update_post_meta( $variation_id, BINDCOMMERCE_PRODUCT_META_VARIATION_SALE_PRICE, "" );

            }   

        }

        $quantity_fields = sanitize_text_field( $_POST[BINDCOMMERCE_PRODUCT_META_VARIATION_QUANTITY][$i] );

        if ( isset( $quantity_fields ) ) {

            $quantity_fields = str_replace(",", ".", $quantity_fields);
            $quantity_fields = str_replace(" ", "", $quantity_fields);

            if (is_numeric($quantity_fields)) {

                update_post_meta( $variation_id, BINDCOMMERCE_PRODUCT_META_VARIATION_QUANTITY, esc_attr( round($quantity_fields) ) );

            } else {

                update_post_meta( $variation_id, BINDCOMMERCE_PRODUCT_META_VARIATION_QUANTITY, "" );

            }   

        }

        
        if ( BindCommerce_Setting::get_tax_amount_status() ) {

            $tax_amount_fields = sanitize_text_field( $_POST[BINDCOMMERCE_PRODUCT_META_VARIATION_TAX_AMOUNT][$i] );

            if ( isset( $tax_amount_fields ) ) {

                $tax_amount_fields = str_replace(",", ".", $tax_amount_fields);
                $tax_amount_fields = str_replace("%", "", $tax_amount_fields);
                $tax_amount_fields = str_replace(" ", "", $tax_amount_fields);

                if (is_numeric($tax_amount_fields)) {

                    update_post_meta( $variation_id, BINDCOMMERCE_PRODUCT_META_VARIATION_TAX_AMOUNT, esc_attr( round($tax_amount_fields, 2) . "%") );

                } else {

                    update_post_meta( $variation_id, BINDCOMMERCE_PRODUCT_META_VARIATION_TAX_AMOUNT, "" );

                }
            }

        }

        if ( BindCommerce_Setting::get_supplement_amount_status() ) {

            $supplement_amount_fields = sanitize_text_field( $_POST[BINDCOMMERCE_PRODUCT_META_VARIATION_SUPPLEMENT_AMOUNT][$i] );

            if ( isset( $supplement_amount_fields ) ) {

                $supplement_amount_fields = str_replace(",", ".", $supplement_amount_fields);
                $supplement_amount_fields = str_replace(" ", "", $supplement_amount_fields);

                if (strpos($supplement_amount_fields, '%') !== false) {

                    $supplement_amount_fields = str_replace("%", "", $supplement_amount_fields);
                    if (is_numeric($supplement_amount_fields)) {

                        update_post_meta( $variation_id, BINDCOMMERCE_PRODUCT_META_VARIATION_SUPPLEMENT_AMOUNT, esc_attr( round($supplement_amount_fields, 2) . "%") );
                    
                    } else {

                        update_post_meta( $variation_id, BINDCOMMERCE_PRODUCT_META_VARIATION_SUPPLEMENT_AMOUNT, "" );
                    
                    }

                } else {

                    if (is_numeric($supplement_amount_fields)) {
                        
                        update_post_meta( $variation_id, BINDCOMMERCE_PRODUCT_META_VARIATION_SUPPLEMENT_AMOUNT, esc_attr( round($supplement_amount_fields, 2) ) );
                    
                    } else {
                        
                        update_post_meta( $variation_id, BINDCOMMERCE_PRODUCT_META_VARIATION_SUPPLEMENT_AMOUNT, "" );
                    
                    }

                }

            }

        }

        if ( BindCommerce_Setting::get_gtin_fields_status() ) {

            $gtin_field = $_POST[BINDCOMMERCE_PRODUCT_META_VARIATION_GTIN][$i];
            if ( isset( $gtin_field ) ) {

                update_post_meta( $variation_id, BINDCOMMERCE_PRODUCT_META_VARIATION_GTIN, esc_attr( $gtin_field ) );

            }

        }

    }

}


if ( !function_exists("bindcommerce_shop_order_columns") ) {

    /**
     * 
     * Adding columns to the WooCommerce order viewer 
     * 
     * @since 1.0.0
     * 
     */
    function bindcommerce_shop_order_columns($columns) {

        $reordered_columns = array();
    
        // Inserting columns to a specific location
        foreach( $columns as $key => $column){
            $reordered_columns[$key] = $column;
            if( $key ==  "order_status" ){
                // Inserting after "Status" column
                $reordered_columns["bindcommerce-order-node"]     = __( "Nodo", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN );
                $reordered_columns["bindcommerce-order-number"]   = __( "Numero d'ordine", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN );
                $reordered_columns["bindcommerce-order-date"]     = __( "Data ricezione d'ordine", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN );
            }
        }
        return $reordered_columns;

    }

}
add_filter( "manage_edit-shop_order_columns", "bindcommerce_shop_order_columns", 20 );


// Add custom order meta data to make it accessible in Order preview template
function bindcommerce_admin_order_preview_add_custom_meta_data( $data, $order ) {
    
    if( $custom_value = $order->get_meta('bindcommerce_order_missing_products') ) {

        $data['bindcommerce_order_missing_products'] = $custom_value; // <= Store the value in the data array.

    }

    return $data;
}
add_filter( 'woocommerce_admin_order_preview_get_order_details', 'bindcommerce_admin_order_preview_add_custom_meta_data', 10, 2 );


// Display custom values in Order preview
function bindcommerce_custom_display_order_data_in_admin(){

    // Call the stored value and display it
    echo '<div class="bindcommerce-missing-products" data-products="{{data.bindcommerce_order_missing_products}}" style="display:none!important;"></div>';

}
add_action( 'woocommerce_admin_order_preview_end', 'bindcommerce_custom_display_order_data_in_admin' );



/**
 * 
 * Adding custom fields meta data for each bindcommerce column
 * 
 * @since 1.0.0
 * 
 */
if ( !function_exists("bindcommerce_orders_list_column_content") ) {

    function bindcommerce_orders_list_column_content( $column, $post_id ) {

        switch ( $column ) {

            case "bindcommerce-order-node":

                $node = get_post_meta( $post_id, BINDCOMMERCE_ORDER_META_GENERAL_NODE, true );

                if(!empty($node)) {

                    echo "<span>" . $node . "</span>";

                } else {

                    echo "<small>-</small>";

                }
                break;

            case "bindcommerce-order-number":
                
                $general_number = get_post_meta( $post_id, BINDCOMMERCE_ORDER_META_GENERAL_NUMBER, true );

                if( !empty($general_number) ) {

                    echo "<span>" . $general_number . "</span>";

                } else {

                    echo "<small>-</small>";

                }

                break;

            case "bindcommerce-order-date":
            
                $order_date = get_post_meta( $post_id, BINDCOMMERCE_ORDER_META_GENERAL_DATE, true );

                if( !empty($order_date) ) {

                    echo "<span>" . $order_date . "</span>";

                } else {

                    echo "<small>-</small>";

                }

                break;

        }

    }

}
add_action( "manage_shop_order_posts_custom_column" , "bindcommerce_orders_list_column_content", 20, 2 );


// Adding Meta container admin shop_order pages
if ( ! function_exists( 'bindcommerce_add_order_meta_boxes' ) ) {

    function bindcommerce_add_order_meta_boxes() {

        global $post;

        $bindcommerce_order_number = get_post_meta( $post->ID, BINDCOMMERCE_ORDER_META_GENERAL_BINDCOMMERCE_NUMBER, true );

        if ( !empty($bindcommerce_order_number) ) {

            add_meta_box( 'bindcommerce_order_fields', __('BindCommerce',BINDCOMMERCE_PLUGIN_TEXT_DOMAIN), 'bindcommerce_fields_for_order_meta_boxes', 'shop_order', 'side', 'core' );
            
        }

    }

}
add_action( 'add_meta_boxes', 'bindcommerce_add_order_meta_boxes' );

// Adding Meta field in the meta container admin shop_order pages
if ( ! function_exists( 'bindcommerce_fields_for_order_meta_boxes' ) ) {

    function bindcommerce_fields_for_order_meta_boxes() {

        global $post;

        $bindcommerce_order_number = get_post_meta( $post->ID, BINDCOMMERCE_ORDER_META_GENERAL_BINDCOMMERCE_NUMBER, true );

        if ( !empty($bindcommerce_order_number) ) {

            $bindcommerce_node                  = get_post_meta( $post->ID, BINDCOMMERCE_ORDER_META_GENERAL_NODE, true );
            $bindcommerce_node_id               = get_post_meta( $post->ID, BINDCOMMERCE_ORDER_META_GENERAL_NODE_ID, true );
            $bindcommerce_technology            = get_post_meta( $post->ID, BINDCOMMERCE_ORDER_META_GENERAL_TECHNOLOGY, true );
            $bindcommerce_general_number        = get_post_meta( $post->ID, BINDCOMMERCE_ORDER_META_GENERAL_NUMBER, true );
            $bindcommerce_date                  = get_post_meta( $post->ID, BINDCOMMERCE_ORDER_META_GENERAL_DATE, true );
            $bindcommerce_last_update           = get_post_meta( $post->ID, BINDCOMMERCE_ORDER_META_GENERAL_LAST_UPDATE, true );
            
            $bindcommerce_carrier               = get_post_meta( $post->ID, BINDCOMMERCE_ORDER_META_SHIPPING_CARRIER, true );
            $bindcommerce_tracking_number       = get_post_meta( $post->ID, BINDCOMMERCE_ORDER_META_SHIPPING_TRACKING_NUMBER, true );
            $bindcommerce_transported_weight    = get_post_meta( $post->ID, BINDCOMMERCE_ORDER_META_SHIPPING_TRANSPORTED_WEIGHT, true );
            $bindcommerce_shipped_time          = get_post_meta( $post->ID, BINDCOMMERCE_ORDER_META_SHIPPING_SHIPPED_TIME, true );
            
            echo "
            <p><b>" .  __( "Numero d'ordine", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN ) . "</b></p>
            <p style=\"border-bottom:solid 1px #eee;padding-bottom:13px;\">" . $bindcommerce_order_number . "</p>

            <p><b>" .  __( "Market", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN ) . "</b></p>
            <p style=\"border-bottom:solid 1px #eee;padding-bottom:13px;\">" . $bindcommerce_technology . "</p>
            
            <p><b>" .  __( "Riferimento ordine Market", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN ) . "</b></p>
            <p style=\"border-bottom:solid 1px #eee;padding-bottom:13px;\">" . $bindcommerce_general_number . "</p>

            <p><b>" .  __( "Nodo", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN ) . "</b></p>
            <p style=\"border-bottom:solid 1px #eee;padding-bottom:13px;\">" . $bindcommerce_node . "</p>

            <p><b>" .  __( "ID nodo", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN ) . "</b></p>
            <p style=\"border-bottom:solid 1px #eee;padding-bottom:13px;\">" . $bindcommerce_node_id . "</p>

            <p><b>" .  __( "Ordine ricevuto", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN ) . "</b></p>
            <p style=\"border-bottom:solid 1px #eee;padding-bottom:13px;\">" . $bindcommerce_date . "</p>

            <p><b>" .  __( "Ultimo aggiornamento", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN ) . "</b></p>
            <p style=\"border-bottom:solid 1px #eee;padding-bottom:13px;\">" . $bindcommerce_last_update . "</p>
            
            <p><b>" .  __( "Spedizioniere", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN ) . "</b></p>
            <p style=\"border-bottom:solid 1px #eee;padding-bottom:13px;\">" . $bindcommerce_carrier . "</p>
            
            <p><b>" .  __( "Codice di tracciabilità", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN ) . "</b></p>
            <p style=\"border-bottom:solid 1px #eee;padding-bottom:13px;\">" . $bindcommerce_tracking_number . "</p>
            
            <p><b>" .  __( "Peso trasportato", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN ) . "</b></p>
            <p style=\"border-bottom:solid 1px #eee;padding-bottom:13px;\">" . $bindcommerce_transported_weight . "</p>
            
            <p><b>" .  __( "Data ed ora di spedizione", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN ) . "</b></p>
            <p style=\"border-bottom:solid 1px #eee;padding-bottom:13px;\">" . $bindcommerce_shipped_time . "</p>
            
            ";

        }        

    }

}

if ( !function_exists("bindcommerce_admin_order_totals_after_tax") ) {

    /**
     * 
     * Add Custom fields in the wc-order-totals
     * 
     * @since 1.0.0
     * 
     */
    function bindcommerce_admin_order_totals_after_tax( $order_id ) {

        $bindcommerce_order_number = get_post_meta( $order_id, BINDCOMMERCE_ORDER_META_GENERAL_BINDCOMMERCE_NUMBER, true );

        if ( !empty($bindcommerce_order_number) ) {

            $bc_total           = get_post_meta( $order_id, BINDCOMMERCE_ORDER_META_AMOUNTS_TOTAL, true );
            $bc_shipping_cost   = get_post_meta( $order_id, BINDCOMMERCE_ORDER_META_AMOUNTS_TOTAL_SHIPPING_COST, true );
            $bc_currency        = get_post_meta( $order_id, BINDCOMMERCE_ORDER_META_AMOUNTS_CURRENCY, true );
            $bc_subtotal        = $bc_total - $bc_shipping_cost;

            ?>

                <?php // Subtotal ?>
                <tr class="bindcommerce-order-subtotal">
                    <td class="label"><?php echo __("Totale per prodotti non presenti (bindCommerce)", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN); ?></td>
                    <td width="1%"></td>
                    <td class="total">
                        <span class="woocommerce-Price-amount amount"><bdi><?php echo $bc_subtotal; ?><span class="woocommerce-Price-currencySymbol"><?php echo $bc_currency; ?></span></bdi></span>				
                    </td>
                </tr>

                <?php // Shipping Cost ?>
                <tr class="bindcommerce-order-shipping-cost">
                    <td class="label"><?php echo __("Costo Spedizione (bindCommerce)", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN); ?></td>
                    <td width="1%"></td>
                    <td class="total">
                        <span class="woocommerce-Price-amount amount"><bdi><?php echo $bc_shipping_cost; ?><span class="woocommerce-Price-currencySymbol"><?php echo $bc_currency; ?></span></bdi></span>				
                    </td>
                </tr>

            <?php

        }
    }

}
add_action('woocommerce_admin_order_totals_after_tax', 'bindcommerce_admin_order_totals_after_tax', 10, 1 );


if ( !function_exists("bindcommerce_wc_shop_order_search_by_custom_meta_data") ) {

    /**
     * 
     * Search WooCommerce order by custom meta data
     * 
     * @since 1.0.0
     * 
     */
    function bindcommerce_wc_shop_order_search_by_custom_meta_data( $search_fields ) {

        $search_fields[] = BINDCOMMERCE_ORDER_META_GENERAL_NUMBER;

        return $search_fields;
    }

}
add_filter( 'woocommerce_shop_order_search_fields', 'bindcommerce_wc_shop_order_search_by_custom_meta_data' );


if ( !function_exists("bindcommerce_wc_get_parent_categories") ) {

    /**
     * 
     * Get WooCommerce categories
     * 
     * @since 1.0.0
     * 
     */
    function bindcommerce_wc_get_parent_categories() {

        $taxonomy     = "product_cat";
        $orderby      = 'name';
        $show_count   = 0;      
        $pad_counts   = 0;      
        $hierarchical = 1;      
        $title        = '';
        $empty        = 0;

        $args = array(
            'taxonomy'     => $taxonomy,
            'orderby'      => $orderby,
            'show_count'   => $show_count,
            'pad_counts'   => $pad_counts,
            'hierarchical' => $hierarchical,
            'title_li'     => $title,
            'hide_empty'   => $empty
        );

        if ( BindCommerce_Addons::is_wpml_active() ) { 
            
            global $sitepress;
            remove_filter('terms_clauses', array($sitepress, 'terms_clauses'));
            $all_categories = get_categories($args);
            add_filter('terms_clauses', array($sitepress, 'terms_clauses'), 10, 3);

        } else {

            $all_categories = get_categories( $args );

        }

        return $all_categories;
        
    }

}


if ( !function_exists("bindcommerce_wc_get_subcategories") ) {

    /**
     * 
     * Get WooCommerce Subcategories
     * 
     * @since 1.0.0
     * 
     */
    function bindcommerce_wc_get_subcategories( $items, &$arg, $level = 0 ) {

        $taxonomy     = 'product_cat';
        $orderby      = 'name';
        $show_count   = 0;
        $pad_counts   = 0;
        $hierarchical = 1;
        $title        = '';
        $empty        = 0;

        if($items) {

            $category_id = $items->term_id;
            $args = array(
                'taxonomy' => $taxonomy,
                'child_of' => 0,
                'parent' => $category_id,
                'orderby' => $orderby,
                'show_count' => $show_count,
                'pad_counts' => $pad_counts,
                'hierarchical' => $hierarchical,
                'title_li' => $title,
                'hide_empty' => $empty
            );

            if ( BindCommerce_Addons::is_wpml_active() ) { 
            
                global $sitepress;
                remove_filter('terms_clauses', array($sitepress, 'terms_clauses'));
                $sub_cats = get_categories($args);
                add_filter('terms_clauses', array($sitepress, 'terms_clauses'), 10, 3);
        
            } else {
        
                $sub_cats = get_categories( $args );
        
            }

            if($sub_cats) {

                foreach ($sub_cats as $sub) {

                    $category_id = $sub->term_id;
                    array_push($arg[0],$sub);
                    array_push($arg[1],$level);
                    bindcommerce_wc_get_subcategories($sub,$arg,$level+1);

                }

            } else {
                return;
            }

        }
        else {
            return;
        }
    }

}


if ( !function_exists('bindcommerce_wc_admin_head') ) {
    
    /**
     * 
     * Add style to Admin head
     * 
     * @since 1.0.0
     */
    function bindcommerce_wc_admin_head() { 

        $action_slug = "shipped"; // The key slug defined for your action button
        ?>
        
        <style>

            input#bindcommerce_export_product_button {
                border: 0;
                padding: 3px 10px;
                margin-top: 7px;
                background: #eaeaea;
                width: 100px;
                text-align: center;
                vertical-align: middle;
                cursor: pointer;
            }
            input#bindcommerce_export_product_button:focus {
                box-shadow: 0 0 0 1px #89aa0d;                
            }
            .bindcommerce_export_product_button_field.dashicons-before.dashicons-update::before {
                margin-top: 14px;
                margin-left: 5px;
            }
            .bindcommerce_settings_options.bindcommerce_settings_tab a:before {
                content: "\f308"!important;
            }
            .order-status.status-shipped{
                color: #fff;
                background: #8A2BE2;
            }
            .wc-action-button-<?php echo $action_slug; ?>::after {
                font-family: woocommerce !important; content: "\e029" !important;
            }
            p.bindcommerce_sync_tip_message_field label{
                display: block;
                width: 100%;
                border-bottom: 1px solid #b7b7b7;
                padding-bottom: 10px;                
            }
            p.bindcommerce_sync_tip_message_field input{                
                display: none;                
            }
            .bindcommerce-order-item, .bindcommerce-table-row-order-preview {
                background: #ffdbdb;
            }

        </style>

        <?php include_once( BINDCOMMERCE_PLUGIN_PATH . 'admin/components/footer.php'); ?>
        
    <?php 

    }

}
add_action("admin_head", "bindcommerce_wc_admin_head");

if ( !function_exists('bindcommerce_wc_admin_footer') ) {
    
    /**
     * 
     * Add scripts to Admin footer
     * 
     * @since 1.0.0
     */
    function bindcommerce_wc_admin_footer() { 

        include_once( BINDCOMMERCE_PLUGIN_PATH . 'admin/components/footer.php');        
    
    }

}
add_action("admin_footer", "bindcommerce_wc_admin_footer" );


if ( !function_exists("bindcommerce_update_product_quantity_new_wc_order") ) {

    /**
     * 
     * Export products quantity when new new order in WC
     * 
     * @since 1.0.0  
     * 
     */
    function bindcommerce_update_product_quantity_new_wc_order( $wc_order_id ) { 
        
        $products_ids       = [];
        $wc_order           = wc_get_order( $wc_order_id );
        $order_items        = $wc_order->get_items(); // Get products that already exist in the order 
        $bc_order_number    = $wc_order->get_meta( BINDCOMMERCE_ORDER_META_GENERAL_BINDCOMMERCE_NUMBER );

        if ( empty($bc_order_number) && !empty($order_items) ) {            

            foreach ( $order_items as $item_id => $item ) {
                
                $products_ids[] = $item->get_product_id();

            }

        }                
        
        if ( !empty($products_ids) ) {        

            $sync = json_decode( 

                BindCommerce_API::export_products( 
                    $products_ids, 
                    "", 
                    "", 
                    "quantity", 
                    "text/xml",
                    false,
                    "incremental"
                ),

            true );
                                
            if (isset($sync["status"]) && $sync["status"] == "error") {
                                
                $errors[] = [
                    "data" => $sync["message"]
                ];
        
            }

            if ( !empty($errors) ) {

                BindCommerce_Logger::error( 
                    __("EXPORT Prodotti: Impossibile completare la sincronizzazione, per maggiori informazioni consulta i log catturati nella sezione dedicata", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),
                    "", 
                    true  
                );
                
            } else { 

                BindCommerce_Logger::info( __("EXPORT Prodotti: Esportazione completata ", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );
                
            }

        }

    }; 

}
add_action( 'woocommerce_update_order', 'bindcommerce_update_product_quantity_new_wc_order', 10, 3 ); 
add_action( 'woocommerce_thankyou', 'bindcommerce_update_product_quantity_new_wc_order', 10, 3 );


if ( !function_exists("bindcommerce_woocommerce_update_product") ) {

    /**
     * 
     * Sync product to bindCommerce when it was updated
     * 
     * @since 1.0.0
     * 
     */
    function bindcommerce_woocommerce_update_product( $product_get_id ) { 

        if ( BindCommerce_Setting::get_sync_product_edit_status() ) {      

            $times = did_action('woocommerce_update_product');

            if( $times === 1){

                $sync = json_decode( 

                    BindCommerce_API::export_products( 
                        $product_get_id, 
                        "", 
                        "", 
                        "full", 
                        "text/xml"
                    ),

                true );
                                    
                if (isset($sync["status"]) && $sync["status"] == "error") {
                                    
                    $errors[] = [
                        "data" => $sync["message"]
                    ];
            
                }

                if ( !empty($errors) ) {

                    BindCommerce_Logger::error( 
                        __("EXPORT Prodotti: Impossibile completare la sincronizzazione per il prodotto con ID: ", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) 
                        . $product_get_id 
                        . __(", per maggiori informazioni consulta i log catturati nella sezione dedicata", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN), 
                        "", 
                        true  
                    );
                    
                } else { 

                    BindCommerce_Logger::info( __("EXPORT Prodotti: Esportazione completata per il prodotto con ID: ", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . $product_get_id );
                    
                }

            }

        }

    };

}
add_action( 'woocommerce_update_product', 'bindcommerce_woocommerce_update_product', 10, 1 ); 


if ( !function_exists("bindcommerce_add_email_order_meta") ) {

    /**
     * 
     * Add order meta to WC order email
     * 
     * @since 1.0.0  
     * 
     */
    function bindcommerce_add_email_order_meta( $wc_order, $sent_to_admin, $plain_text ){

        $bc_order_number = $wc_order->get_meta( BINDCOMMERCE_ORDER_META_GENERAL_BINDCOMMERCE_NUMBER );

        if ($sent_to_admin && !empty($bc_order_number) ) {  
            
            if ( $plain_text === false ) {
            
                echo '<h2>' . __("bindCommerce", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . '</h2>';
            
            } else {
            
                echo __("bindCommerce", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . '\n';
            
            }       

            $missing_products = BindCommerce_DB::get_result("
        
                SELECT meta_value 
                FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . "postmeta" . " " . "
                WHERE post_id = '" . $wc_order->get_order_number() . "' 
                AND meta_key = '". BINDCOMMERCE_ORDER_META_MISSING_PRODUCTS . "';
                
            ");

            if ( !empty($missing_products) ) { 

                $missing_products = json_decode($missing_products, true); 

                if ( $plain_text === false ) {
            
                    echo '<p style="color:#d80000;">' . __("Prodotto(i) non presente su WooCommerce", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . '</p>';
                
                } else {
                
                    echo __("Prodotto(i) non presente su WooCommerce", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . '\n';
                
                }  

                $i = 0;
                foreach ($missing_products as $product) {
 
                    if ( $plain_text === false ) {

                        echo '
                        <table class="td" cellspacing="0" cellpadding="6" border="1" style="background: #ffdbdb; color: #636363; border: 1px solid #000; vertical-align: middle; width: 100%;">
                            <thead>
                                <tr>
                                    <th class="td" scope="col" style="color: #636363; border: 1px solid #000; vertical-align: middle; padding: 12px; text-align: left;">' . __( 'Prodotto', BINDCOMMERCE_PLUGIN_TEXT_DOMAIN ) . '</th>
                                    <th class="td" scope="col" style="color: #636363; border: 1px solid #000; vertical-align: middle; padding: 12px; text-align: left;">' . __( 'Quantità', BINDCOMMERCE_PLUGIN_TEXT_DOMAIN ) . '</th>
                                    <th class="td" scope="col" style="color: #636363; border: 1px solid #000; vertical-align: middle; padding: 12px; text-align: left;">' . __( 'Prezzo', BINDCOMMERCE_PLUGIN_TEXT_DOMAIN ) . '</th>
                                </tr>
                            </thead>
                            <tbody>
                                <tr class="order_item">
                                    <td class="td" style="color: #636363; border: 1px solid #000; padding: 12px; text-align: left; vertical-align: middle; word-wrap: break-word;">
                                        ' . $product[$i]["product"]["Description"] . '		
                                    </td>
                                    <td class="td" style="color: #636363; border: 1px solid #000; padding: 12px; text-align: left; vertical-align: middle;">
                                        ' . $product[$i]["product"]["Qty"] . '			
                                    </td>
                                    <td class="td" style="color: #636363; border: 1px solid #000; padding: 12px; text-align: left; vertical-align: middle;">
                                        <span class="woocommerce-Price-amount amount">' . $product[$i]["product"]["Total"] . '<span class="woocommerce-Price-currencySymbol">' . $product[$i]["product"]["Currency"] . '</span></span>		
                                    </td>
                                </tr>
                            </tbody>
                            <tfoot></tfoot>
                        </table>
                        ';
                    
                    } else {
                    
                        echo __("Prodotto:", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . ' ' . $product[$i]["product"]["Description"] . '\n';
                        echo __("Quantità:", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . ' ' . $product[$i]["product"]["Qty"] . '\n';
                        echo __("Prezzo:", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)   . ' ' . $product[$i]["product"]["Total"] . $product[$i]["product"]["Currency"] . '\n';
                    
                    } 

                    $i++;

                }

                if ( $plain_text === false ) {
            
                    echo '<br />';
                
                } else {
                
                    echo '\n';
                
                }
                
            }

            $bc_total                       = $wc_order->get_meta( BINDCOMMERCE_ORDER_META_AMOUNTS_TOTAL );
            $bc_shipping_cost               = $wc_order->get_meta( BINDCOMMERCE_ORDER_META_AMOUNTS_TOTAL_SHIPPING_COST );
            $bc_currency                    = $wc_order->get_meta( BINDCOMMERCE_ORDER_META_AMOUNTS_CURRENCY );            
            $bc_node                        = $wc_order->get_meta( BINDCOMMERCE_ORDER_META_GENERAL_NODE );
            $bc_node_id                     = $wc_order->get_meta( BINDCOMMERCE_ORDER_META_GENERAL_NODE_ID );
            $bc_technology                  = $wc_order->get_meta( BINDCOMMERCE_ORDER_META_GENERAL_TECHNOLOGY );
            $bc_general_number              = $wc_order->get_meta( BINDCOMMERCE_ORDER_META_GENERAL_NUMBER );
            $bc_date                        = $wc_order->get_meta( BINDCOMMERCE_ORDER_META_GENERAL_DATE );
            $bc_last_update                 = $wc_order->get_meta( BINDCOMMERCE_ORDER_META_GENERAL_LAST_UPDATE );
            
            $bc_shipping_carrier            = $wc_order->get_meta( BINDCOMMERCE_ORDER_META_SHIPPING_CARRIER );
            $bc_shipping_tracking_number    = $wc_order->get_meta( BINDCOMMERCE_ORDER_META_SHIPPING_TRACKING_NUMBER );
            $bc_shipping_transported_weight = $wc_order->get_meta( BINDCOMMERCE_ORDER_META_SHIPPING_TRANSPORTED_WEIGHT );
            $bc_shipping_shipped_time       = $wc_order->get_meta( BINDCOMMERCE_ORDER_META_SHIPPING_SHIPPED_TIME );

            $bc_subtotal        = $bc_total - $bc_shipping_cost;    
            
            if ( $plain_text === false ) {
            
                echo '<h2>' . __("Dettagli d'ordine (bindCommerce)", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . '</h2>
                <ul>
                    <li>
                        <strong>' . __("Numero d'ordine", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) .'</strong> ' . $bc_order_number . '
                    </li>
                    <li>
                        <strong>' . __("Market:", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) .'</strong> ' . $bc_technology . '
                    </li>
                    <li>
                        <strong>' . __("Riferimento ordine Market:", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) .'</strong> ' . $bc_general_number . '
                    </li>
                    <li>
                        <strong>' . __("Nodo:", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) .'</strong> ' . $bc_node . '
                    </li>
                    <li>
                        <strong>' . __("ID nodo:", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) .'</strong> ' . $bc_node_id . '
                    </li>
                    <li>
                        <strong>' . __("Ordine ricevuto", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) .'</strong> ' . $bc_date . '
                    </li>
                    <li>
                        <strong>' . __("Ultimo aggiornamento", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) .'</strong> ' . $bc_last_update . '
                    </li>
                    <li>
                        <strong>' . __("Totale per prodotti non presenti", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) .'</strong> ' . $bc_subtotal . $bc_currency . '
                    </li>
                    <li>
                        <strong>'. __("Costo Spedizione", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . '</strong> ' . $bc_shipping_cost . $bc_currency . '
                    </li>   

                    <li>
                        <strong>'. __("Spedizioniere", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . '</strong> ' . $bc_shipping_carrier . '
                    </li> 
                    <li>
                        <strong>'. __("Codice di tracciabilità", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . '</strong> ' . $bc_shipping_tracking_number . '
                    </li> 
                    <li>
                        <strong>'. __("Peso trasportato", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . '</strong> ' . $bc_shipping_transported_weight . '
                    </li> 
                    <li>
                        <strong>'. __("Data ed ora di spedizione", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . '</strong> ' . $bc_shipping_shipped_time . '
                    </li>
                </ul>
                ';
            
            } else {
            
                echo __("Dettagli d'ordine (bindCommerce)", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) . '\n'
                . __("Numero d'ordine", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)                     . ' ' . $bc_order_number . '\n'
                . __("Market:", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)                             . ' ' . $bc_technology . '\n'
                . __("Riferimento ordine Market:", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)          . ' ' . $bc_general_number . '\n'
                . __("Nodo:", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)                               . ' ' . $bc_node . '\n'
                . __("ID nodo:", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)                            . ' ' . $bc_node_id . '\n'
                . __("Ordine ricevuto", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)                     . ' ' . $bc_date . '\n'
                . __("Ultimo aggiornamento", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)                . ' ' . $bc_last_update . '\n'
                . __("Totale per prodotti non presenti", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)    . ' ' . $bc_subtotal . $bc_currency . '\n'
                . __("Costo Spedizione", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)                    . ' ' . $bc_shipping_cost . $bc_currency . '\n'
                
                . __("Spedizioniere", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)                      . ' ' . $bc_shipping_carrier . '\n'                
                . __("Codice di tracciabilità", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)            . ' ' . $bc_shipping_tracking_number . '\n'
                . __("Peso trasportato", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)                   . ' ' . $bc_shipping_transported_weight . '\n'
                . __("Data ed ora di spedizione", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)          . ' ' . $bc_shipping_shipped_time . '\n'
                ;
            
            }            

        }
        
    }

}
add_action( 'woocommerce_email_order_meta', 'bindcommerce_add_email_order_meta', 10, 3 );


?>