<?php 

if ( ! defined( 'ABSPATH' ) ) { 
    exit; 
}


if ( !function_exists("bindcommerce_admin_menu") ) {

    /**
     * 
     * Add menu to WP Backend 
     * 
     * @since 1.0.0
     * 
     */
    function bindcommerce_admin_menu() {

        add_menu_page(    
            "bindCommerce", 
            "bindCommerce",  
            "manage_options",        
            "bindcommerce/admin/pages/page-bindcommerce-settings.php",        
            "",        
            BindCommerce_Tools::get_plugin_url() . "admin/images/bindcommerce-dash-logo.png" ,        
            9       
        );    

    }    

}
add_action( "admin_menu", "bindcommerce_admin_menu" ); 


if ( !function_exists("bindcommerce_admin_register_scripts_and_styles") ) {

    /**
     * 
     * Register admin scripts and styles
     * 
     * @since 1.0.0
     *  
     */
    function bindcommerce_admin_register_scripts_and_styles() {
        
        wp_register_style(  "bindcommerce-icons",   BindCommerce_Tools::get_plugin_url() . "admin/css/dashicons.css", array(), BINDCOMMERCE_PLUGIN_VERSION );    
        wp_register_style(  "bindcommerce-style",   BindCommerce_Tools::get_plugin_url() . "admin/css/style.css", array(), BINDCOMMERCE_PLUGIN_VERSION );    
        wp_register_script( "bindcommerce-script",  BindCommerce_Tools::get_plugin_url() . "admin/js/main.js", array(), BINDCOMMERCE_PLUGIN_VERSION );  

    }   

}
add_action( "admin_enqueue_scripts", "bindcommerce_admin_register_scripts_and_styles" );


if ( !function_exists("bindcommerce_admin_load_scripts_and_style") ) {

    /**
     * 
     * Load admin scripts and styles
     * 
     * @since 1.0.0
     * 
     */
    function bindcommerce_admin_load_scripts_and_style( $hook ) {
        
        wp_enqueue_style( "bindcommerce-icons" );
        wp_enqueue_style( "bindcommerce-style" );
        wp_enqueue_script( "bindcommerce-script" );
        
    }

}
add_action( "admin_enqueue_scripts", "bindcommerce_admin_load_scripts_and_style" );


if ( !function_exists("bindcommerce_load_textdomain") ) {

    /**
     * 
     * Load the correct textdomain language
     * 
     * @since 1.0.0
     * 
     */
    function bindcommerce_load_textdomain() {

        // Default languages directory for bindCommerce
        $lang_dir = BINDCOMMERCE_PLUGIN_PATH . 'languages/';

        /**
         * Filters the languages directory path to use for bindCommerce
         *
         * @param string $lang_dir The languages directory path.
         */
        $lang_dir = apply_filters( 'bindcommerce_languages_directory', $lang_dir );

        // Traditional WordPress plugin locale filter.
        global $wp_version;

        $get_locale = get_locale();

        if ( $wp_version >= 4.7 ) {
            $get_locale = get_user_locale();
        }

        /**
         * Language Locale for bindCommerce
         *
         * @var $get_locale The locale to use.
         * Uses get_user_locale()` in WordPress 4.7 or greater,
         * otherwise uses `get_locale()`.
         */
        $locale = apply_filters( 'plugin_locale', $get_locale, BINDCOMMERCE_PLUGIN_TEXT_DOMAIN );
        $mofile = sprintf( '%1$s-%2$s.mo', BINDCOMMERCE_PLUGIN_TEXT_DOMAIN, $locale );

        // Setup paths to current locale file.
        $mofile_local  = $lang_dir . $mofile;
        $mofile_global = WP_LANG_DIR . '/plugins/' . $mofile;

        if ( file_exists( $mofile_global ) ) {

            // Look in global /wp-content/languages/%plugin-folder-name%/ folder.
            load_textdomain( BINDCOMMERCE_PLUGIN_TEXT_DOMAIN, $mofile_global );

        } elseif ( file_exists( $mofile_local ) ) {

            // Look in local /wp-content/plugins/%plugin-folder-name%/languages/ folder.
            load_textdomain( BINDCOMMERCE_PLUGIN_TEXT_DOMAIN, $mofile_local );

        } else {

            // Load the default language files.
            load_plugin_textdomain( BINDCOMMERCE_PLUGIN_TEXT_DOMAIN, false, $lang_dir );

        }

    }
    
}
add_action( "plugins_loaded", "bindcommerce_load_textdomain" );


?>
